function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _async_to_generator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
import { readFile } from 'node:fs/promises';
import { fileSyntax, getDefaultSassImplementation, resolveCanonicalize } from './sass-utils.js';
let sassEngine;
import * as fs from 'node:fs';
import path from 'node:path';
import { fileURLToPath, pathToFileURL } from 'node:url';
export const transformSass = function() {
    var _ref = _async_to_generator(function*(filePath, options) {
        const { sourcemap } = options;
        if (!sassEngine) {
            try {
                sassEngine = getDefaultSassImplementation();
            } catch (e) {
                console.error(e);
                process.exit(1);
            }
        }
        const syntax = fileSyntax(filePath);
        const basedir = path.dirname(filePath);
        const contents = yield readFile(filePath, 'utf-8');
        const warnings = [];
        const alias = options.alias || {};
        const result = yield sassEngine.compileStringAsync(contents, {
            sourceMapIncludeSources: true,
            sourceMap: sourcemap,
            syntax,
            alertColor: false,
            logger: {
                warn (message, options) {
                    if (!options.span) {
                        warnings.push({
                            text: `sass warning: ${message}`
                        });
                    } else {
                        var _options_span_url;
                        var _options_span_url_pathname;
                        const filename = (_options_span_url_pathname = (_options_span_url = options.span.url) === null || _options_span_url === void 0 ? void 0 : _options_span_url.pathname) !== null && _options_span_url_pathname !== void 0 ? _options_span_url_pathname : path;
                        const esbuildMsg = {
                            text: message,
                            location: {
                                file: filename,
                                line: options.span.start.line,
                                column: options.span.start.column,
                                lineText: options.span.text
                            },
                            detail: {
                                deprecation: options.deprecation,
                                stack: options.stack
                            }
                        };
                        warnings.push(esbuildMsg);
                    }
                }
            },
            importer: {
                load (canonicalUrl) {
                    const pathname = fileURLToPath(canonicalUrl);
                    const contents = fs.readFileSync(pathname, 'utf8');
                    return {
                        contents,
                        syntax: fileSyntax(pathname),
                        sourceMapUrl: sourcemap ? canonicalUrl : undefined
                    };
                },
                canonicalize (url) {
                    const urlPath = resolveCanonicalize(filePath, url, alias);
                    if (urlPath) {
                        return pathToFileURL(urlPath);
                    }
                    return null;
                }
            }
        });
        const sourceMap = result.sourceMap;
        if (sourceMap) {
            sourceMap.sourceRoot = basedir;
            sourceMap.sources = sourceMap.sources.map((source)=>{
                return path.relative(basedir, source.startsWith('data:') ? filePath : fileURLToPath(source));
            });
        }
        const imports = result.loadedUrls.map((url)=>fileURLToPath(url));
        return {
            css: result.css,
            map: result.sourceMap ? JSON.stringify(result.sourceMap) : '',
            imports,
            warnings
        };
    });
    return function transformSass(filePath, options) {
        return _ref.apply(this, arguments);
    };
}();
